Package: broom
Type: Package
Title: Convert Statistical Analysis Objects into Tidy Data Frames
Version: 0.4.2
Date: 2016-02-13
Authors@R: c(
    person("David", "Robinson", email = "admiral.david@gmail.com", role = c("aut", "cre")),
    person("Matthieu", "Gomez", email = "mattg@princeton.edu", role = "ctb"),
    person("Boris", "Demeshev", email = "boris.demeshev@gmail.com", role = "ctb"),
    person("Dieter", "Menne", email = "dieter.menne@menne-biomed.de", role = "ctb"),
    person("Benjamin", "Nutter", email = "nutter@battelle.org", role = "ctb"),
    person("Luke", "Johnston", email = "luke.johnston@mail.utoronto.ca", role = "ctb"),
    person("Ben", "Bolker", email = "bolker@mcmaster.ca", role = "ctb"),
    person("Francois", "Briatte", email = "f.briatte@gmail.com", role = "ctb"),
    person("Jeffrey", "Arnold", email = "jeffrey.arnold@gmail.com", role = "ctb"),
    person("Jonah", "Gabry", email = "jsg2201@columbia.edu", role = "ctb"),
    person("Luciano", "Selzer", email = "luciano.selzer@gmail.com", role = "ctb"),
    person("Gavin", "Simpson", email = "ucfagls@gmail.com", role = "ctb"),
    person("Jens", "Preussner", email = " jens.preussner@mpi-bn.mpg.de", role = "ctb"),
    person("Jay", "Hesselberth", email = "jay.hesselberth@gmail.com", role = "ctb"),
    person("Hadley", "Wickham", email = "hadley@rstudio.com", role = "ctb")
    )
Maintainer: David Robinson <admiral.david@gmail.com>
Description: Convert statistical analysis objects from R into tidy data frames,
    so that they can more easily be combined, reshaped and otherwise processed
    with tools like 'dplyr', 'tidyr' and 'ggplot2'. The package provides three
    S3 generics: tidy, which summarizes a model's statistical findings such as
    coefficients of a regression; augment, which adds columns to the original
    data such as predictions, residuals and cluster assignments; and glance, which
    provides a one-row summary of model-level statistics.
Imports: plyr, dplyr, tidyr, psych, stringr, reshape2, nlme, methods
Suggests: knitr, boot, survival, gam, glmnet, lfe, Lahman, MASS, sp,
        maps, maptools, multcomp, testthat, lme4, zoo, lmtest, plm,
        biglm, ggplot2, nnet, geepack, AUC, ergm, network,
        statnet.common, xergm, btergm, binGroup, Hmisc, bbmle, gamlss,
        rstan, rstanarm, brms, coda, gmm, Matrix, ks, purrr, orcutt,
        mgcv, lmodel2, poLCA, mclust, covr, lsmeans, betareg, robust,
        akima
URL: http://github.com/tidyverse/broom
BugReports: http://github.com/tidyverse/broom/issues
VignetteBuilder: knitr
License: MIT + file LICENSE
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2017-02-13 21:57:25 UTC; drobinson
Author: David Robinson [aut, cre],
  Matthieu Gomez [ctb],
  Boris Demeshev [ctb],
  Dieter Menne [ctb],
  Benjamin Nutter [ctb],
  Luke Johnston [ctb],
  Ben Bolker [ctb],
  Francois Briatte [ctb],
  Jeffrey Arnold [ctb],
  Jonah Gabry [ctb],
  Luciano Selzer [ctb],
  Gavin Simpson [ctb],
  Jens Preussner [ctb],
  Jay Hesselberth [ctb],
  Hadley Wickham [ctb]
Repository: CRAN
Date/Publication: 2017-02-13 23:34:38
Built: R 3.3.2; ; 2017-05-03 14:35:25 UTC; windows
