# Generated by roxygen2: do not edit by hand

S3method(augment,"NULL")
S3method(augment,Mclust)
S3method(augment,betareg)
S3method(augment,coxph)
S3method(augment,data.frame)
S3method(augment,decomposed.ts)
S3method(augment,default)
S3method(augment,felm)
S3method(augment,glmRob)
S3method(augment,ivreg)
S3method(augment,kmeans)
S3method(augment,lm)
S3method(augment,lmRob)
S3method(augment,lme)
S3method(augment,loess)
S3method(augment,merMod)
S3method(augment,mlm)
S3method(augment,nlrq)
S3method(augment,nls)
S3method(augment,plm)
S3method(augment,poLCA)
S3method(augment,prcomp)
S3method(augment,rowwise_df)
S3method(augment,rq)
S3method(augment,rqs)
S3method(augment,smooth.spline)
S3method(augment,speedlm)
S3method(augment,stl)
S3method(augment,survreg)
S3method(augment,tbl_df)
S3method(augment_,rowwise_df)
S3method(glance,"NULL")
S3method(glance,Arima)
S3method(glance,Gam)
S3method(glance,Mclust)
S3method(glance,aareg)
S3method(glance,betareg)
S3method(glance,biglm)
S3method(glance,binDesign)
S3method(glance,cch)
S3method(glance,coxph)
S3method(glance,cv.glmnet)
S3method(glance,data.frame)
S3method(glance,default)
S3method(glance,ergm)
S3method(glance,felm)
S3method(glance,fitdistr)
S3method(glance,gam)
S3method(glance,glm)
S3method(glance,glmRob)
S3method(glance,glmnet)
S3method(glance,gmm)
S3method(glance,htest)
S3method(glance,ivreg)
S3method(glance,kmeans)
S3method(glance,list)
S3method(glance,lm)
S3method(glance,lmRob)
S3method(glance,lme)
S3method(glance,lmodel2)
S3method(glance,matrix)
S3method(glance,merMod)
S3method(glance,mlm)
S3method(glance,muhaz)
S3method(glance,multinom)
S3method(glance,nlrq)
S3method(glance,nls)
S3method(glance,orcutt)
S3method(glance,plm)
S3method(glance,poLCA)
S3method(glance,pyears)
S3method(glance,ridgelm)
S3method(glance,rlm)
S3method(glance,rowwise_df)
S3method(glance,rq)
S3method(glance,rqs)
S3method(glance,smooth.spline)
S3method(glance,speedlm)
S3method(glance,stanreg)
S3method(glance,summary.lm)
S3method(glance,summaryDefault)
S3method(glance,survdiff)
S3method(glance,survexp)
S3method(glance,survfit)
S3method(glance,survreg)
S3method(glance,tbl_df)
S3method(glance_,rowwise_df)
S3method(tidy,"NULL")
S3method(tidy,Arima)
S3method(tidy,Gam)
S3method(tidy,Line)
S3method(tidy,Lines)
S3method(tidy,Mclust)
S3method(tidy,Polygon)
S3method(tidy,Polygons)
S3method(tidy,SpatialLinesDataFrame)
S3method(tidy,SpatialPolygons)
S3method(tidy,SpatialPolygonsDataFrame)
S3method(tidy,TukeyHSD)
S3method(tidy,aareg)
S3method(tidy,acf)
S3method(tidy,anova)
S3method(tidy,aov)
S3method(tidy,aovlist)
S3method(tidy,betareg)
S3method(tidy,biglm)
S3method(tidy,binDesign)
S3method(tidy,binWidth)
S3method(tidy,boot)
S3method(tidy,brmsfit)
S3method(tidy,btergm)
S3method(tidy,cch)
S3method(tidy,character)
S3method(tidy,cld)
S3method(tidy,coeftest)
S3method(tidy,confint.glht)
S3method(tidy,coxph)
S3method(tidy,cv.glmnet)
S3method(tidy,data.frame)
S3method(tidy,default)
S3method(tidy,density)
S3method(tidy,dgCMatrix)
S3method(tidy,dgTMatrix)
S3method(tidy,dist)
S3method(tidy,emmGrid)
S3method(tidy,ergm)
S3method(tidy,felm)
S3method(tidy,fitdistr)
S3method(tidy,ftable)
S3method(tidy,gam)
S3method(tidy,gamlss)
S3method(tidy,geeglm)
S3method(tidy,glht)
S3method(tidy,glmRob)
S3method(tidy,glmnet)
S3method(tidy,gmm)
S3method(tidy,htest)
S3method(tidy,ivreg)
S3method(tidy,kappa)
S3method(tidy,kde)
S3method(tidy,kmeans)
S3method(tidy,list)
S3method(tidy,lm)
S3method(tidy,lmRob)
S3method(tidy,lme)
S3method(tidy,lmodel2)
S3method(tidy,logical)
S3method(tidy,lsmobj)
S3method(tidy,manova)
S3method(tidy,map)
S3method(tidy,matrix)
S3method(tidy,merMod)
S3method(tidy,mle2)
S3method(tidy,muhaz)
S3method(tidy,multinom)
S3method(tidy,nlrq)
S3method(tidy,nls)
S3method(tidy,numeric)
S3method(tidy,orcutt)
S3method(tidy,pairwise.htest)
S3method(tidy,plm)
S3method(tidy,poLCA)
S3method(tidy,power.htest)
S3method(tidy,prcomp)
S3method(tidy,pyears)
S3method(tidy,rcorr)
S3method(tidy,ref.grid)
S3method(tidy,ridgelm)
S3method(tidy,rjags)
S3method(tidy,roc)
S3method(tidy,rowwise_df)
S3method(tidy,rq)
S3method(tidy,rqs)
S3method(tidy,sparseMatrix)
S3method(tidy,spec)
S3method(tidy,speedlm)
S3method(tidy,stanfit)
S3method(tidy,stanreg)
S3method(tidy,summary.glht)
S3method(tidy,summary.lm)
S3method(tidy,summaryDefault)
S3method(tidy,survdiff)
S3method(tidy,survexp)
S3method(tidy,survfit)
S3method(tidy,survreg)
S3method(tidy,table)
S3method(tidy,tbl_df)
S3method(tidy,ts)
S3method(tidy,zoo)
S3method(tidy_,rowwise_df)
export(augment)
export(augment_columns)
export(bootstrap)
export(confint_tidy)
export(finish_glance)
export(fix_data_frame)
export(glance)
export(inflate)
export(tidy)
export(tidyMCMC)
import(dplyr)
import(tidyr)
importFrom(nlme,VarCorr)
importFrom(nlme,ranef)
importFrom(plyr,ldply)
importFrom(plyr,rbind.fill)
importFrom(psych,describe)
importFrom(reshape2,melt)
importFrom(stats,AIC)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,fitted)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,residuals)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
importFrom(utils,head)
