---
title: "Available methods"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Available methods}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

The following methods are currently available in `broom`:


```{R echo = FALSE, message = FALSE}
library(broom)
library(dplyr)
library(stringr)

method_df <- function(method_name) {
  m <- as.vector(methods(method_name))
  tibble::tibble(
    class = str_remove(m, str_c(method_name, "[.]")),
    !!method_name := "x"
  )
}

method_df("tidy") %>%
  left_join(method_df("glance")) %>%
  left_join(method_df("augment")) %>%
  mutate_all(tidyr::replace_na, "") %>%
  knitr::kable()
```

